setup_phys

Function setup_phys 

pub fn setup_phys() -> WiringPi<Phys>
This is identical to setup(), however it allows the calling programs to use the physical pin numbers on the P1 connector only.

This function needs to be called with root privileges.